==> 1.0.3.tar.gz: d-fi/README.md <==
## d-fi

> A streaming music downloader.

![Screenshot](screenshot.png)

d-fi is a program for downloading music from streaming music services.

Remember that the artists and studios put a lot of work into making music - purchase the original music to support them.

#### Features

- Supports single tracks, albums, artists, and playlists
- Music quality selection (MP3 - 128 kbps, MP3 - 320 kbps, FLAC - 1411 kbps)
- Auto tagging MP3 & FLAC (including album cover)
- Download a list of links from "downloads.txt"
- CLI and module support

### Supported sites

- Deezer
- Tidal
- Spotify

> Tidal and Spotify tracks will be sourced from Deezer

#### Install

`npm i d-fi -g`

or

`yarn global add d-fi`

Run `d-fi` to start.

#### CLI parameters

| Parameter        | Short           | Default  | Supported values                | Description                          |
| :--------------- | :-------------- | :------- | :------------------------------ | :----------------------------------- |
| `--quality`      | `-q`            | `320`    | 128/320/FLAC                    | The quality of the files to download |
| `--path`         | `-p`            | `Music`  | Relative or absolute path       | The path to download the files to    |
| `--url`          | `-u or nothing` |          | album/artist/playlist/track url | Downloads from url                   |
| `--downloadmode` | `-d`            | `single` | `all` for "downloads.txt"       | Downloads multiple urls from list    |
| `--help`         | `-h`            |          | _Nothing_                       | Shows the CLI help                   |

#### Donations

If you want to show your appreciation, you can donate me on [ko-fi](https://ko-fi.com/Z8Z5KDA6) or [BMC](https://www.buymeacoffee.com/sayem). Thanks!

> Telegram community group: [@dFiCommunity](https://t.me/dFiCommunity)

#### Disclaimer

> d-fi was not developed for pirating music but educational and private usage.
>
> It may be illegal to use this in your country,
>
> I am not responsible in any way for the usage of others.

---

> Made with :heart: & [:coffee:](https://sayem.eu.org/donate) by Sayem
>
> Based on SMLoadr and Deezloader Remix

==> 1.1.1.tar.gz: d-fi/README.md <==
## d-fi

> A streaming music downloader.

![Screenshot](screenshot.png)

d-fi is a program for downloading music from streaming music services.

Remember that the artists and studios put a lot of work into making music - purchase the original music to support them.

### Features

- Supports single tracks, albums, artists, and playlists
- Music quality selection (MP3 - 128 kbps, MP3 - 320 kbps, FLAC - 1411 kbps)
- Auto tagging MP3 & FLAC (including album cover and lyrics)
- Download a list of links from "downloads.txt"
- Track search support
- CLI and module support

### Supported sites

- Deezer
- Tidal
- Spotify

> Tidal and Spotify tracks will be sourced from Deezer

### Install

> `npm i d-fi -g`

or

> `yarn global add d-fi`

Run `d-fi` to start.

> Pre-built binary [here](https://notabug.org/sayem314/d-fi/releases)

### CLI parameters

| Parameter        | Short           | Default  | Supported values                | Description                          |
| :--------------- | :-------------- | :------- | :------------------------------ | :----------------------------------- |
| `--quality`      | `-q`            | `320`    | 128/320/FLAC                    | The quality of the files to download |
| `--path`         | `-p`            | `Music`  | Relative or absolute path       | The path to download the files to    |
| `--url`          | `-u or nothing` |          | album/artist/playlist/track url | Downloads from url                   |
| `--downloadmode` | `-d`            | `single` | `all` for "downloads.txt"       | Downloads multiple urls from list    |
| `--help`         | `-h`            |          | _Nothing_                       | Shows the CLI help                   |

### Donations

If you want to show your appreciation, you can donate me on [ko-fi](https://ko-fi.com/Z8Z5KDA6) or [buy me a coffee](https://www.buymeacoffee.com/sayem). Thanks!

> Telegram community group: [@dFiCommunity](https://t.me/dFiCommunity)

### Disclaimer

> d-fi was not developed for pirating music but educational and private usage.
>
> It may be illegal to use this in your country,
>
> I am not responsible in any way for the usage of others.

---

> Made with :heart: & :coffee: by Sayem
>
> Based on SMLoadr and Deezloader Remix
